@@ -33,8 +33,9 @@ if ! grep -q "100[0-9]:100[0-9]" /etc/passwd; then
 	echo "$USER:x:1000:" >> /etc/group
 	echo "$USER:!::" >> /etc/gshadow
 	status
-	# Audio group.
-	sed -i s/"audio:x:20:"/"audio:x:20:$USER"/ /etc/group
+	# Audio and cdrom group.
+	addgroup $USER audio
+	addgroup $USER cdrom
 	# /home/$USER files from /etc/skel.
 	if [ -d /etc/skel ]; then
 		cp -a /etc/skel /home/$USER
@@ -73,6 +74,8 @@ do
 			echo -n "Setting system locale to: $LANG... "
 			echo "LANG=$LANG" > /etc/locale.conf
 			echo "LC_ALL=$LANG" >> /etc/locale.conf
+			[ ! -d /usr/lib/locale/$LANG ] && localedef \
+				-i $LANG -c -f UTF-8 /usr/lib/locale/$LANG &
 			status ;;
 		kmap=*)
 			# Check for a specified keymap (kmap=*).
@@ -100,7 +103,7 @@ do
 			fi
 			if [ -n "$DEVID" ] && grep -q "$DEVID" /proc/partitions ; then
 				echo "Mounting /home on /dev/$DEVID... "
-				mv /home/$USER /tmp/$USER-files
+				[ -d /home/$USER ] && mv /home/$USER /tmp/$USER-files
 				mount /dev/$DEVID /home -o uid=1000,gid=1000 2>/dev/null \
 					|| mount /dev/$DEVID /home
 				# Check if swap file must be generated in /home: swap=size (Mb).
