@@ -1,19 +1,27 @@
 #!/bin/sh
 # /etc/init.d/hwconf.sh - SliTaz hardware configuration.
 #
-# This script configure the sound card and screen. Tazhw is used earlier
+# This script configures the sound card and screen. Tazhw is used earlier
 # at boot time to autoconfigure PCI and USB devices.
 #
 . /etc/init.d/rc.functions
 
 # Parse cmdline args for boot options (See also rcS and bootopts.sh).
+XARG=""
 for opt in `cat /proc/cmdline`
 do
 	case $opt in
 		sound=*)
 			DRIVER=${opt#sound=} ;;
-		xargs=*)
-			XARGS=${opt#xargs=} ;;
+		xarg=*)
+			XARG="$XARG ${opt#xarg=}" ;;
+		screen=text)
+				# Disable X.
+				echo -n "Disabling X login manager: slim..."
+				. /etc/rcS.conf
+				RUN_DAEMONS=`echo $RUN_DAEMONS | sed s/' slim'/''/`
+				sed -i s/"RUN_DAEMONS.*"/"RUN_DAEMONS=\"$RUN_DAEMONS\"/" /etc/rcS.conf
+				status ;;
 		screen=*)
 			SCREEN=${opt#screen=} ;;
 		*)
@@ -63,13 +71,29 @@ else
 	echo "Unable to configure sound card."
 fi
 
-# Screen size config for slim/Xvesa (last config dialog before login).
-if [ ! -s /etc/X11/screen.conf -a -x /usr/bin/slim ]; then
+# Xorg auto configuration.
+if [ ! -s /etc/X11/xorg.conf -a -x /usr/bin/Xorg ]; then
+	echo "Configuring Xorg..."
 	# $HOME is not yet set.
 	HOME=/root
-	if [ -n "$XARGS" ]; then
+	Xorg -configure
+	mv -f /root/xorg.conf.new /etc/X11/xorg.conf
+	sed -i 's|/usr/bin/Xvesa|/usr/bin/Xorg|' /etc/slim.conf
+	sed -i s/"^xserver_arguments"/'\#xserver_arguments'/ /etc/slim.conf
+	tazx config-xorg
+fi
+
+# Screen size config for slim/Xvesa (last config dialog before login).
+#
+# NOTE: Xvesa is unmaintained, package will be removed and all related
+# code cleaned 
+#
+if [ ! -s /etc/X11/screen.conf -a -x /usr/bin/Xvesa ]; then
+	# $HOME is not yet set.
+	HOME=/root
+	if [ -n "$XARG" ]; then
 		# Add an extra argument to xserver_arguments (xarg=-2button)
-		sed -i "s|-screen|$XARG -screen|" /etc/slim.conf
+		sed -i "s| -screen|$XARG -screen|" /etc/slim.conf
 	fi
 	if [ -n "$SCREEN" ]; then
 		case "$SCREEN" in
@@ -86,6 +110,14 @@ if [ ! -s /etc/X11/screen.conf -a -x /usr/bin/slim ]; then
 					awk '{ printf "%s %s\n",$2 }' \
 					| sort -nr | grep x[1-2][4-6] | head -n 1`
 				tazx `cat /etc/X11/wm.default` ;;
+			1024x600*|800x480*)
+				set -- $(echo $SCREEN | sed 's/x/ /g')
+				915resolution -l 2>/dev/null | \
+				grep " ${1}x" | awk -v h=$1 -v v=$2 \
+				'END {system("915resolution " $2 " " h " " v)}'
+				# Use specified screen resolution.
+				export NEW_SCREEN=$SCREEN
+				tazx `cat /etc/X11/wm.default` ;;
 			*)
 				# Use specified screen resolution.
 				export NEW_SCREEN=$SCREEN
