@@ -60,6 +60,10 @@ wifi() {
 		[ -n "$WIFI_MODE" ] && IWCONFIG_ARGS="$IWCONFIG_ARGS mode $WIFI_MODE"
 		[ -n "$WIFI_CHANNEL" ] && IWCONFIG_ARGS="$IWCONFIG_ARGS channel $WIFI_CHANNEL"
 		
+		if [ "$WIFI_KEY_TYPE" == "" ]; then
+			iwconfig $WIFI_INTERFACE essid "$WIFI_ESSID" $IWCONFIG_ARGS
+		fi
+		
 		[ -n "$WIFI_KEY" ] && case "$WIFI_KEY_TYPE" in
 			wep|WEP) 
 			     IWCONFIG_ARGS="$IWCONFIG_ARGS key $WIFI_KEY"
@@ -89,7 +93,7 @@ ap_scan=1
 network={
 	ssid="$WIFI_ESSID"
 	scan_ssid=1
-	proto=WPA
+	proto=WPA RSN
 	key_mgmt=WPA-PSK
 	psk="$WIFI_KEY"
 	priority=5
@@ -151,6 +155,8 @@ static_ip() {
 		echo "Configuring static IP on $INTERFACE: $IP..."
 		/sbin/ifconfig $INTERFACE $IP netmask $NETMASK up
 		/sbin/route add default gateway $GATEWAY
+		# Dirty trick: wpa_supplicant waits for wpa_cli
+		wpa_cli -B
 		# Multi-DNS server in $DNS_SERVER.
 		/bin/mv /etc/resolv.conf /tmp/resolv.conf.$$
 		for NS in $DNS_SERVER
